about summary refs log tree commit diff stats
path: root/layout.c
diff options
context:
space:
mode:
authorAnselm R. Garbe <garbeam@gmail.com>2007-08-18 13:48:05 +0200
committerAnselm R. Garbe <garbeam@gmail.com>2007-08-18 13:48:05 +0200
commit50be6c8b67c500ee4aa07919609fa80785fd389d (patch)
treeb6cb11170b9273e079a536e6a70c6d8d5bcb7e98 /layout.c
parent7d156dee1e80f7d26aa0a31a6d2c75af06cbaa9a (diff)
downloaddwm-50be6c8b67c500ee4aa07919609fa80785fd389d.tar.gz
cleaned up settags-handling
Diffstat (limited to 'layout.c')
-rw-r--r--layout.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/layout.c b/layout.c
index 573de57..030c282 100644
--- a/layout.c
+++ b/layout.c
@@ -10,7 +10,7 @@ typedef struct {
 } Layout;
 
 unsigned int blw = 0;
-static unsigned int sellayout = 0; /* default */
+static unsigned int ltidx = 0; /* default */
 
 static void
 floating(void) { /* default floating layout */
@@ -36,7 +36,7 @@ arrange(void) {
 			unban(c);
 		else
 			ban(c);
-	layouts[sellayout].arrange();
+	layouts[ltidx].arrange();
 	focus(NULL);
 	restack();
 }
@@ -76,25 +76,25 @@ focusprev(const char *arg) {
 const char *
 getsymbol(void)
 {
-	return layouts[sellayout].symbol;
+	return layouts[ltidx].symbol;
 }
 
 Bool
 isfloating(void) {
-	return layouts[sellayout].arrange == floating;
+	return layouts[ltidx].arrange == floating;
 }
 
 Bool
 isarrange(void (*func)())
 {
-	return func == layouts[sellayout].arrange;
+	return func == layouts[ltidx].arrange;
 }
 
 void
 initlayouts(void) {
 	unsigned int i, w;
 
 	/* TODO deserialize sellayout if present */
 	nlayouts = sizeof layouts / sizeof layouts[0];
 	for(blw = i = 0; i < nlayouts; i++) {
 		w = textw(layouts[i].symbol);
@@ -143,14 +143,14 @@ setlayout(const char *arg) {
 	int i;
 
 	if(!arg) {
-		if(++sellayout == nlayouts)
-			sellayout = 0;;
+		if(++ltidx == nlayouts)
+			ltidx = 0;;
 	}
 	else {
 		i = atoi(arg);
 		if(i < 0 || i >= nlayouts)
 			return;
-		sellayout = i;
+		ltidx = i;
 	}
 	if(sel)
 		arrange();
@@ -76,25 +76,25 @@ focusprev(const char *arg) {
 	unsigned int i, w;
 
-	/* TODO deserialize sellayout if present */
+	/* TODO deserialize ltidx if present */
 	nlayouts = sizeof layouts / sizeof layouts[0];
 	for(blw = i = 0; i < nlayouts; i++) {